@@ -4,7 +4,7 @@ This module simply stores the version number, as well as a changelog.
 """
 
 # Version number
-__version__ = '1.9.2'
+__version__ = '1.10.1'
 
 
 # Changelog
@@ -12,6 +12,25 @@ def changelog():
     """
     PyBDSF Changelog.
     -----------------------------------------------------------------------
+    2022/02/14 - Version 1.10.1: Fix Numpy API incompatibility issue
+
+    2022/02/09 - Version 1.10.0
+
+    2022/02/09 - Update some functions as required by scipy versions >= 1.8.0
+        (PR #172)
+
+    2022/02/09 - Fix build issues with Python 3.8, end support for Python < 3.6,
+        add support for Python 3.8 and 3.9, and make installation of the interactive
+        pybdsf shell optional (PR #169)
+
+    2022/02/09 - Improve handling of the beam in the spectral index module
+        (PR #165)
+
+    2021/05/05 - Improve handling of large, complex islands (PR #160)
+
+    2020/04/07 - Allow a file to be supplied for the ch0 image used in the
+        spectral index module (PR #127)
+
     2019/12/05 - Version 1.9.2
 
     2019/12/04 - Fix exception behaviour if spline order change does not work
