@@ -1,6 +1,12 @@
+# some functions
 from __future__ import print_function
 from __future__ import absolute_import
-# some functions
+
+try:
+    # For Python 2
+    basestring = basestring
+except NameError:
+    basestring = str
 
 def poly(c,x):
     """ y = Sum { c(i)*x^i }, i=0,len(c)"""
@@ -527,18 +533,18 @@ def std(y):
 def imageshift(image, shift):
     """ Shifts a 2d-image by the tuple (shift). Positive shift is to the right and upwards.
     This is done by fourier shifting. """
-    import scipy
+    import scipy.fft
     from scipy import ndimage
 
     shape=image.shape
 
-    f1=scipy.fft(image, shape[0], axis=0)
-    f2=scipy.fft(f1, shape[1], axis=1)
+    f1=scipy.fft.fft(image, shape[0], axis=0)
+    f2=scipy.fft.fft(f1, shape[1], axis=1)
 
     s=ndimage.fourier_shift(f2,shift, axis=0)
 
-    y1=scipy.ifft(s, shape[1], axis=1)
-    y2=scipy.ifft(y1, shape[0], axis=0)
+    y1=scipy.fft.ifft(s, shape[1], axis=1)
+    y2=scipy.fft.ifft(y1, shape[0], axis=0)
 
     return y2.real
 
@@ -1346,10 +1352,6 @@ def read_image_from_file(filename, img, indir, quiet=False):
 
     mylog.info("Final data shape (npol, nchan, x, y): " + str(data.shape))
 
-    ### and make a copy of it to get proper layout & byteorder
-    data = N.array(data, order='C',
-                   dtype=data.dtype.newbyteorder('='))
-
     return data, hdr
 
 
@@ -2062,7 +2064,12 @@ def eval_func_tuple(f_args):
 def start_samp_proxy():
     """Starts (registers) and returns a SAMP proxy"""
     import os
-    import xmlrpclib
+    try:
+        # Python 3
+        from xmlrpc.client import ServerProxy
+    except ImportError:
+        # Python 2
+        from xmlrpclib import ServerProxy
 
     lockfile = os.path.expanduser('~/.samp')
     if not os.path.exists(lockfile):
@@ -2075,7 +2082,7 @@ def start_samp_proxy():
                 HUB_PARAMS[key] = value.strip()
 
     # Set up proxy
-    s = xmlrpclib.ServerProxy(HUB_PARAMS['samp.hub.xmlrpc.url'])
+    s = ServerProxy(HUB_PARAMS['samp.hub.xmlrpc.url'])
 
     # Register with Hub
     metadata = {"samp.name": 'PyBDSM', "samp.description.text": 'PyBDSM: the Python Blob Detection and Source Measurement software'}
@@ -2245,3 +2252,19 @@ def bstat(indata, mask, kappa_npixbeam):
     r = numpy.sqrt(sigma**2 * (r1 / (r1 - 2.0*kappa*numpy.exp(-kappa**2/2.0))))
 
     return m_raw, r_raw, m, r, iter
+
+
+def centered(arr, newshape):
+    """Return the center newshape portion of the array
+
+    This function is a copy of the private _centered() function in
+    scipy.signal.signaltools
+    """
+    import numpy as np
+
+    newshape = np.asarray(newshape)
+    currshape = np.array(arr.shape)
+    startind = (currshape - newshape) // 2
+    endind = startind + newshape
+    myslice = [slice(startind[k], endind[k]) for k in range(len(endind))]
+    return arr[tuple(myslice)]
