@@ -73,7 +73,10 @@ def process(img, **kwargs):
             raise
     except KeyboardInterrupt:
         mylogger.userinfo(mylog, "\n\033[31;1mAborted\033[0m")
-        return False
+        if img._is_interactive_shell:
+            return False
+        else:
+            raise
 
 def get_op_chain(img):
     """Determines the optimal Op chain for an Image object.
@@ -272,7 +275,9 @@ def get_op_chain(img):
                     img.completed_Ops.remove('polarisation')
                 found = True
             if k in make_residimage_opts:
-                if hasattr(img, 'resid_gaus_arr'): del img.resid_gaus_arr
+                if hasattr(img, 'resid_gaus_arr'):
+                    del img.resid_gaus_arr
+                    img.resid_gaus_arr = None  # set to init state
                 if hasattr(img, 'model_gaus_arr'): del img.model_gaus_arr
                 if hasattr(img, 'resid_shap_arr'): del img.resid_shap_arr
                 if hasattr(img, 'model_shap_arr'): del img.model_shap_arr
@@ -928,7 +933,10 @@ def export_image(img, outfile=None, img_format='fits', pad_image = False,
             raise
     except KeyboardInterrupt:
         mylogger.userinfo(mylog, "\n\033[31;1mAborted\033[0m")
-        return False
+        if img._is_interactive_shell:
+            return False
+        else:
+            raise
 
 
 def write_catalog(img, outfile=None, format='bbs', srcroot=None, catalog_type='gaul',
