@@ -248,12 +248,12 @@ class Op_rmsimage(Op):
 
                 mean_fits_name,rms_fits_name=opts.rmsmean_map_filename
 
-                mylogger.userinfo(mylog, "Skipping mean and rms image computation")
-                mylogger.userinfo(mylog, "   Openning mean image: %s"%mean_fits_name)
+                mylogger.userinfo(mylog, "Skipping mean and rms image computation as external images supplied")
+                mylogger.userinfo(mylog, "   Opening mean image: %s"%mean_fits_name)
                 # mean = pyfits.open(mean_fits_name, mode="readonly")[0].data
                 mean, hdr = read_image_from_file(mean_fits_name, img, img.indir)
                 CheckShape(mean); mean = mean[0,0]
-                mylogger.userinfo(mylog, "   Openning rms image: %s"%rms_fits_name)
+                mylogger.userinfo(mylog, "   Opening rms image: %s"%rms_fits_name)
                 # rms = pyfits.open(rms_fits_name, mode="readonly")[0].data
                 rms, hdr = read_image_from_file(rms_fits_name, img, img.indir)
                 CheckShape(rms); rms = rms[0,0]
