@@ -19,7 +19,6 @@ from . import functions as func
 import gc
 from numpy import array, product
 import scipy.signal
-from scipy.signal.signaltools import _centered
 from .readimage import Op_readimage
 from .preprocess import Op_preprocess
 from .rmsimage import Op_rmsimage
@@ -40,8 +39,9 @@ try:
     N.fft.ifftn = pyfftw.interfaces.numpy_fft.ifftn
     scipy.signal.signaltools.fftn = pyfftw.interfaces.scipy_fftpack.fftn
     scipy.signal.signaltools.ifftn = pyfftw.interfaces.scipy_fftpack.ifftn
+    has_pyfftw = True
 except ImportError:
-    pass
+    has_pyfftw = False
 
 
 class Op_wavelet_atrous(Op):
@@ -561,9 +561,9 @@ def fftconvolve(in1, in2, mode="full", pad_to_power_of_two=True, numcores=1):
             osize = s1
         else:
             osize = s2
-        return _centered(ret, osize)
+        return func.centered(ret, osize)
     elif mode == "valid":
-        return _centered(ret, abs(s2 - s1) + 1)
+        return func.centered(ret, abs(s2 - s1) + 1)
 
 
 def rebase_bbox(box,minv):
@@ -690,7 +690,8 @@ def check_islands_for_overlap(img, wimg):
 
     # Make "images" of island ids for overlaping regions
     orig_islands = wav_rankim_bool * (img.pyrank + 1) - 1
-    bar.start()
+    if not img.opts.quiet:
+        bar.start()
     for idx, wvisl in enumerate(wimg.islands):
         if len(wvisl.gaul) > 0:
             # Get unique island IDs. If an island overlaps with one
